// Used by ppsspp.rc
//

#define VS_USER_DEFINED                 100
#define IDR_MENU1                       101
#define IDD_DISASM                      102
#define IDC_FUNCTIONLIST                103
#define IDC_DISASMVIEW                  104
#define IDC_GOTOPC                      105
#define IDC_LEFTTABS                    106
#define IDC_RAM                         107
#define IDC_STEPOVER                    108
#define IDC_TABDATATYPE                 109
#define IDR_GEDBG_MENU                  110
#define ID_MEMVIEW_GOTOINDISASM         112
#define IDI_PPSSPP                      115
#define IDI_STOPDISABLE                 118
#define ID_DEBUG_DISASSEMBLY            119
#define WHEEL_DELTA                     120
#define ID_DEBUG_LOG                    121
#define ID_DEBUG_MEMORYBASE             122
#define ID_FILE_OPEN_NEW_INSTANCE       123
#define ID_FILE_LOADSTATEFILE           126
#define ID_FILE_SAVESTATEFILE           127
#define ID_EMULATION_RESET              130
#define IDD_ABOUTBOX                    133
#define ID_DEBUG_LOADMAPFILE            134
#define ID_OPTIONS_FULLSCREEN           154
#define IDD_MEMORY                      160
#define ID_DEBUG_MEMORYVIEW             161
#define IDR_ACCELS                      162
#define IDR_POPUPMENUS                  169
#define ID_DISASM_GOTOINMEMORYVIEW      197
#define ID_DISASM_TOGGLEBREAKPOINT      198
#define ID_MEMVIEW_DUMP                 199
#define ID_DEBUG_RESETSYMBOLTABLE       212
#define IDI_STOP                        223
#define IDD_INPUTBOX                    226
#define IDD_USERPASSWORDBOX             227
#define IDD_VFPU                        231
#define IDD_BREAKPOINT                  233
#define ID_FILE_LOAD_DIR                234
#define IDR_DEBUGACCELS                 237
#define ID_DEBUG_DISPLAYMEMVIEW         238
#define ID_DEBUG_DISPLAYBREAKPOINTLIST  239
#define ID_DEBUG_DISPLAYTHREADLIST      240
#define ID_DEBUG_DISPLAYSTACKFRAMELIST  241
#define ID_DEBUG_ADDBREAKPOINT          242
#define ID_DEBUG_STEPOVER               243
#define ID_DEBUG_STEPINTO               244
#define ID_DEBUG_RUNTOLINE              245
#define ID_DEBUG_STEPOUT                246
#define ID_DEBUG_DISPLAYREGISTERLIST    247
#define ID_DEBUG_DISPLAYFUNCTIONLIST    248
#define ID_MEMVIEW_COPYADDRESS          249
#define IDD_GEDEBUGGER                  250
#define IDD_TABDISPLAYLISTS             251
#define IDD_GEDBG_TAB_VALUES            252
#define IDD_DUMPMEMORY                  253
#define IDD_GEDBG_TAB_VERTICES          254
#define IDD_GEDBG_TAB_MATRICES          255
#define IDD_GEDBG_STEPCOUNT             256
#define IDD_CPUWATCH                    257
#define IDD_EDITSYMBOLS                 258

#define IDC_STOPGO                      1001
#define IDC_ADDRESS                     1002
#define IDC_DEBUG_COUNT                 1003
#define IDC_SEARCH_BOX                  1004
#define IDC_STEP                        1009
#define IDC_VERSION                     1010
#define IDC_MEMVIEW                     1069
#define IDC_GOTOLR                      1070
#define IDC_GOTOINT                     1071
#define IDC_MEMSORT                     1073
#define IDC_SYMBOLS                     1097
#define IDC_INPUTBOX                    1098
#define IDC_MODENORMAL                  1099
#define IDC_MODESYMBOLS                 1100
#define IDC_PASSWORDBOX                 1101
#define IDC_SEARCH_RESULTS              1102
#define IDC_REGIONS                     1142
#define IDC_REGLIST                     1146
#define IDC_VALUENAME                   1148
#define IDC_PASSWORDNAME                1149
#define IDC_SHOWVFPU                    1161
#define IDC_BREAKPOINTLIST              1164
#define IDC_DEBUGMEMVIEW                1165
#define IDC_BREAKPOINT_OK               1166
#define IDC_BREAKPOINT_CANCEL           1167
#define IDC_BREAKPOINT_ADDRESS          1168
#define IDC_BREAKPOINT_SIZE             1169
#define IDC_BREAKPOINT_CONDITION        1170
#define IDC_BREAKPOINT_EXECUTE          1171
#define IDC_BREAKPOINT_MEMORY           1172
#define IDC_BREAKPOINT_READ             1173
#define IDC_BREAKPOINT_WRITE            1174
#define IDC_BREAKPOINT_ENABLED          1175
#define IDC_BREAKPOINT_LOG              1176
#define IDC_BREAKPOINT_ONCHANGE         1177
#define IDC_THREADLIST                  1178
#define IDC_THREADNAME                  1179
#define IDC_DISASMSTATUSBAR             1180
#define IDC_STACKFRAMES                 1181
#define IDC_GEDBG_VALUES                1182
#define IDC_DUMP_USERMEMORY             1183
#define IDC_DUMP_VRAM                   1184
#define IDC_DUMP_SCRATCHPAD             1185
#define IDC_DUMP_CUSTOMRANGE            1186
#define IDC_DUMP_STARTADDRESS           1187
#define IDC_DUMP_SIZE                   1188
#define IDC_DUMP_FILENAME               1189
#define IDC_DUMP_BROWSEFILENAME         1190
#define IDC_GEDBG_FRAMEBUFADDR          1191
#define IDC_GEDBG_TEXADDR               1192
#define IDC_GEDBG_FBTABS                1193
#define IDC_GEDBG_VERTICES              1194
#define IDC_GEDBG_RAWVERTS              1195
#define IDC_GEDBG_MATRICES              1196
#define IDC_GEDBG_FORCEOPAQUE           1197
#define IDC_GEDBG_SHOWCLUT              1198
#define IDC_BREAKPOINT_LOG_FORMAT       1199
#define IDC_SHOWOFFSETS                 1200
#define IDC_GEDBG_PRIMCOUNTER           1201
#define IDC_BUTTON_SEARCH               1204
#define IDC_EDITSYMBOLS_SCAN            1205
#define IDC_EDITSYMBOLS_REMOVE          1206
#define IDC_EDITSYMBOLS_ADDRESS         1207
#define IDC_EDITSYMBOLS_SIZE            1208
#define IDC_EDITSYMBOLS_OK              1209
#define IDC_EDITSYMBOLS_CANCEL          1210

#define ID_FILE_EXIT                     40000
#define ID_DEBUG_SAVEMAPFILE             40001
#define ID_DISASM_RUNTOHERE              40004
#define ID_MEMVIEW_COPYVALUE_8           40005
#define ID_DISASM_COPYINSTRUCTIONDISASM  40006
#define ID_DISASM_COPYINSTRUCTIONHEX     40007
#define ID_EMULATION_SPEEDLIMIT          40008
#define ID_TOGGLE_BREAK                  40009
#define ID_EMULATION_STOP                40010
#define ID_FILE_LOAD                     40011
#define ID_HELP_ABOUT                    40012
#define ID_DISASM_FOLLOWBRANCH           40013
#define ID_DEBUG_IGNOREILLEGALREADS      40014
#define ID_DISASM_COPYADDRESS            40015
#define ID_REGLIST_GOTOINMEMORYVIEW      40016
#define ID_REGLIST_COPYVALUE             40017
#define ID_REGLIST_COPY                  40018
#define ID_REGLIST_GOTOINDISASM          40019
#define ID_REGLIST_CHANGE                40020
#define ID_DISASM_RENAMEFUNCTION         40021
#define ID_DISASM_SETPCTOHERE            40022
#define ID_HELP_OPENWEBSITE              40023
#define ID_OPTIONS_SCREENAUTO            40024
#define ID_OPTIONS_SCREEN1X              40025
#define ID_OPTIONS_SCREEN2X              40026
#define ID_OPTIONS_SCREEN3X              40027
#define ID_OPTIONS_SCREEN4X              40028
#define ID_OPTIONS_SCREEN5X              40029
#define ID_OPTIONS_HARDWARETRANSFORM     40030
#define IDC_STEPHLE                      40032
#define ID_OPTIONS_LINEARFILTERING       40033
#define ID_OPTIONS_AUTOMAXQUALITYFILTERING 40043
#define ID_OPTIONS_SMART2DTEXTUREFILTERING 40003
#define ID_FILE_QUICKSAVESTATE           40034
#define ID_FILE_QUICKLOADSTATE           40035
#define ID_FILE_QUICKSAVESTATE_HC        40036
#define ID_FILE_QUICKLOADSTATE_HC        40037
#define ID_OPTIONS_CONTROLS              40038
#define ID_DEBUG_BREAKONLOAD             40039
#define ID_DEBUG_DUMPNEXTFRAME           40040
#define ID_OPTIONS_FRAMESKIP             40044
#define IDC_MEMCHECK                     40045
#define ID_FILE_MEMSTICK                 40046
#define ID_FILE_LOAD_MEMSTICK            40047
#define ID_EMULATION_SOUND               40048
#define ID_OPTIONS_MIPMAP                40049
#define ID_TEXTURESCALING_OFF            40050
#define ID_TEXTURESCALING_XBRZ           40051
#define ID_TEXTURESCALING_HYBRID         40052
#define ID_TEXTURESCALING_2X             40053
#define ID_TEXTURESCALING_3X             40054
#define ID_TEXTURESCALING_4X             40055
#define ID_TEXTURESCALING_5X             40056
#define ID_TEXTURESCALING_DEPOSTERIZE    40057
#define ID_TEXTURESCALING_BICUBIC        40058
#define ID_TEXTURESCALING_HYBRID_BICUBIC 40059
#define ID_OPTIONS_TOPMOST               40063
#define ID_HELP_OPENFORUM                40064
#define ID_OPTIONS_VSYNC                 40065
#define ID_DEBUG_TAKESCREENSHOT          40066
#define ID_DEBUG_RESTARTGRAPHICS         40070
#define ID_OPTIONS_TEXTUREFILTERING_AUTO 40067
#define ID_OPTIONS_NEARESTFILTERING      40068
#define ID_DISASM_DISASSEMBLETOFILE      40069
#define ID_DISASM_DISABLEBREAKPOINT      40071
#define ID_DISASM_THREAD_FORCERUN        40072
#define ID_DISASM_THREAD_KILL            40073
#define ID_FILE_SAVESTATE_NEXT_SLOT      40074
#define ID_FILE_SAVESTATE_NEXT_SLOT_HC   40075
#define ID_OPTIONS_SKIP_BUFFER_EFFECTS   40078
#define ID_OPTIONS_FRAMESKIP_0           40079
#define ID_OPTIONS_FRAMESKIP_1           40080
#define ID_OPTIONS_FRAMESKIP_2           40081
#define ID_OPTIONS_FRAMESKIP_3           40082
#define ID_OPTIONS_FRAMESKIP_4           40083
#define ID_OPTIONS_FRAMESKIP_5           40084
#define ID_OPTIONS_FRAMESKIP_6           40085
#define ID_OPTIONS_FRAMESKIP_7           40086
#define ID_OPTIONS_FRAMESKIP_8           40087
#define ID_OPTIONS_FRAMESKIP_AUTO        40088
#define ID_OPTIONS_FRAMESKIPDUMMY        40089
#define ID_OPTIONS_RESOLUTIONDUMMY       40090
#define ID_DISASM_ASSEMBLE               40091
#define ID_DISASM_ADDNEWBREAKPOINT       40092
#define ID_DISASM_EDITBREAKPOINT         40093
#define IDC_DUMP_INCLUDEHACKS            40094
#define ID_EMULATION_CHEATS              40096
#define ID_HELP_CHINESE_FORUM            40097
#define ID_OPTIONS_MORE_SETTINGS         40098
#define ID_FILE_SAVESTATE_SLOT_1         40099
#define ID_FILE_SAVESTATE_SLOT_2         40100
#define ID_FILE_SAVESTATE_SLOT_3         40101
#define ID_FILE_SAVESTATE_SLOT_4         40102
#define ID_FILE_SAVESTATE_SLOT_5         40103
#define ID_OPTIONS_WINDOW1X              40104
#define ID_OPTIONS_WINDOW2X              40105
#define ID_OPTIONS_WINDOW3X              40106
#define ID_OPTIONS_WINDOW4X              40107
#define ID_OPTIONS_WINDOW5X              40108
#define ID_DEBUG_SHOWDEBUGSTATISTICS     40110
#define ID_OPTIONS_SCREEN6X              40111
#define ID_OPTIONS_SCREEN7X              40112
#define ID_OPTIONS_SCREEN8X              40113
#define ID_OPTIONS_SCREEN9X              40114
#define ID_OPTIONS_SCREEN10X             40115
#define ID_DEBUG_GEDEBUGGER              40116
#define IDC_GEDBG_STEPDRAW               40117
#define IDC_GEDBG_RESUME                 40118
#define IDC_GEDBG_FRAME                  40119
#define IDC_GEDBG_MAINTAB                40120
#define IDC_GEDBG_TEX                    40121
#define IDC_GEDBG_STEP                   40122
#define IDC_GEDBG_LISTS_ALLLISTS         40123
#define IDC_GEDBG_LISTS_STACK            40124
#define IDC_GEDBG_LISTS_SELECTEDLIST     40125
#define ID_OPTIONS_SHADER_MENU           40126
#define IDC_DEBUG_BOTTOMTABS             40127
#define ID_DEBUG_HIDEBOTTOMTABS          40128
#define ID_DEBUG_TOGGLEBOTTOMTABTITLES   40129
#define ID_GEDBG_SETSTALLADDR            40130
#define ID_GEDBG_GOTOPC                  40131
#define ID_GEDBG_GOTOADDR                40132
#define IDC_GEDBG_STEPTEX                40133
#define IDC_GEDBG_STEPFRAME              40134
#define IDC_GEDBG_BREAKTEX               40135
#define ID_OPTIONS_PAUSE_FOCUS           40136
#define IDC_GEDBG_STEPPRIM               40138
#define ID_DISASM_ADDFUNCTION            40139
#define ID_DISASM_REMOVEFUNCTION         40140
#define ID_OPTIONS_LANGUAGE              40141
#define ID_MEMVIEW_COPYVALUE_16          40142
#define ID_MEMVIEW_COPYVALUE_32          40143
#define ID_MEMVIEW_COPYFLOAT_32          40229
#define ID_EMULATION_SWITCH_UMD          40144
#define ID_DEBUG_EXTRACTFILE             40145
#define ID_OPTIONS_IGNOREWINKEY          40146
#define IDC_MODULELIST                   40147
#define IDC_GEDBG_TEXLEVELDOWN           40148
#define IDC_GEDBG_TEXLEVELUP             40149
#define ID_DEBUG_LOADSYMFILE             40150
#define ID_DEBUG_SAVESYMFILE             40151
#define ID_OPTIONS_BUFLINEARFILTER       40152
#define ID_OPTIONS_BUFNEARESTFILTER      40153
#define ID_OPTIONS_DIRECT3D9             40154
#define ID_OPTIONS_OPENGL                40155
#define ID_EMULATION_ROTATION_H          40156
#define ID_EMULATION_ROTATION_V          40157
#define ID_EMULATION_ROTATION_H_R        40158
#define ID_EMULATION_ROTATION_V_R        40159
#define ID_OPTIONS_DISPLAY_LAYOUT        40160
#define ID_OPTIONS_VULKAN                40161
#define IDC_GEDBG_BREAKTARGET            40162
#define ID_GEDBG_COPYALL                 40163
#define ID_GEDBG_WATCH                   40164
#define ID_FILE_DUMPFRAMES               40165
#define ID_FILE_USEFFV1                  40166
#define ID_FILE_DUMPAUDIO                40167
#define ID_HELP_GITHUB                   40168
#define IDC_GEDBG_RECORD                 40169
#define ID_GEDBG_EXPORT_IMAGE            40170
#define ID_GEDBG_ENABLE_PREVIEW          40171
#define ID_OPTIONS_WINDOW6X              40172
#define ID_OPTIONS_WINDOW7X              40173
#define ID_OPTIONS_WINDOW8X              40174
#define ID_OPTIONS_WINDOW9X              40175
#define ID_OPTIONS_WINDOW10X             40176
#define ID_EMULATION_PAUSE               40177
#define ID_HELP_DISCORD                  40178
#define IDC_GEDBG_STEPCURVE              40179
#define ID_OPTIONS_FRAMESKIPTYPE_COUNT   40180
#define ID_OPTIONS_FRAMESKIPTYPE_PRCNT   40181
#define ID_FILE_MENU                     40182
#define ID_EMULATION_MENU                40183
#define ID_DEBUG_MENU                    40184
#define ID_OPTIONS_MENU                  40185
#define ID_HELP_MENU                     40186
#define ID_FILE_SAVESTATE_SLOT_MENU      40187
#define ID_FILE_RECORD_MENU              40188
#define ID_EMULATION_ROTATION_MENU       40189
#define ID_OPTIONS_SCREEN_MENU           40190
#define ID_OPTIONS_WINDOW_MENU           40191
#define ID_OPTIONS_BACKEND_MENU          40192
#define ID_OPTIONS_RENDERMODE_MENU       40193
#define ID_OPTIONS_FRAMESKIP_MENU        40194
#define ID_OPTIONS_FRAMESKIPTYPE_MENU    40195
#define ID_OPTIONS_TEXTUREFILTERING_MENU 40196
#define ID_OPTIONS_SCREENFILTER_MENU     40197
#define ID_OPTIONS_TEXTURESCALING_MENU   40198
#define IDC_GEDBG_STEPCOUNT              40199
#define IDC_GEDBG_STEPCOUNT_DEC          40200
#define IDC_GEDBG_STEPCOUNT_INC          40201
#define IDC_GEDBG_STEPCOUNT_JUMP         40202
#define IDC_GEDBG_STEPCOUNT_COMBO        40203
#define ID_FILE_DUMP_VIDEO_OUTPUT        40204
#define ID_EMULATION_CHAT                40205
#define IDC_MEMVIEW_STATUS               40206
#define ID_MEMVIEW_EXTENTBEGIN           40207
#define ID_MEMVIEW_EXTENTEND             40208
#define ID_GEDBG_ACTIONS_MENU            40209
#define ID_GEDBG_STEP_MENU               40210
#define ID_GEDBG_BREAK_MENU              40211
#define IDC_GEDBG_FLUSH                  40212
#define IDC_GEDBG_FLUSHAUTO              40213
#define IDI_BREAKPOINT_SMALL             40214
#define IDC_GEDBG_SETPRIMFILTER          40215
#define IDC_GEDBG_RIGHTTAB               40216
#define ID_OPTIONS_DIRECT3D11            40217
#define IDC_GEDBG_TOPRIGHTTAB            40218
#define ID_GEDBG_SHOWONLEFT              40219
#define ID_GEDBG_SHOWONRIGHT             40220
#define ID_GEDBG_SHOWONTOPRIGHT          40221
#define IDC_GEDBG_STEPVSYNC              40222
#define ID_GEDBG_SETCOND                 40223
#define ID_GEDBG_COPY_IMAGE              40224
#define ID_GEDBG_COPY_IMAGE_ALPHA        40225
#define ID_GEDBG_TRACK_PIXEL             40226
#define ID_GEDBG_TRACK_PIXEL_STOP        40227
#define ID_DISASM_NOPINSTRUCTION         40228
#define IDC_WATCHLIST                    40230
#define ID_DISASM_DELETEBREAKPOINT       40231
#define IDC_DISASM_FMT_HEX               40232
#define IDC_DISASM_FMT_INT               40233
#define IDC_DISASM_FMT_FLOAT             40234
#define IDC_DISASM_FMT_STR               40235
#define ID_DISASM_EDITSYMBOLS            40236


// Dummy option to let the buffered rendering hotkey cycle through all the options.
#define ID_OPTIONS_BUFFEREDRENDERINGDUMMY 40500
#define IDC_STEPOUT                       40501
#define ID_HELP_BUYGOLD                   40502

#define IDC_STATIC                      -1

// Next default values for new objects
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        258
#define _APS_NEXT_COMMAND_VALUE         40236
#define _APS_NEXT_CONTROL_VALUE         1202
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
